cordova.define("talkingdata-sdk.TalkingDataSDK", function(require, exports, module) {
var exec = require('cordova/exec');

var TalkingDataSDK = {
  /**
   * TalkingData SDK初始化方法。
   * @param {string} appId            : 应用的唯一标识，统计后台注册得到
   * @param {string} channelId        : 渠道名（可选）。如“AppStore”
   * @param {string} custom           : 自定义参数（可选）。
   */
  init: function (appId, channelId, custom) {
    exec(null, null, 'TalkingDataSDK', 'init', [appId, channelId, custom]);
  },

  /**
   * 开启后台时长统计
   */
  backgroundSessionEnabled: function () {
    exec(null, null, 'TalkingDataSDK', 'backgroundSessionEnabled', []);
  },

  /**
   * 获取 TDID，并将其作为参数传入 JS 的回调函数
   * @param {object}  callBack        : 处理 TDID 的回调函数
   */
  getDeviceId: function (callBack) {
    exec(callBack, null, 'TalkingDataSDK', 'getDeviceId', []);
  },

  /**
   * 获取 OAID，并将其作为参数传入 JS 的回调函数
   * @param {object}  callBack        : 处理 OAID 的回调函数
   */
  getOAID: function (callBack) {
    exec(callBack, null, 'TalkingDataSDK', 'getOAID', []);
  },

  /**
   * 关闭日志
   */
  setVerboseLogDisable: function () {
    exec(null, null, 'TalkingDataSDK', 'setVerboseLogDisable', []);
  },

  /**
   * 设置位置信息
   * @param {number}  latitude        : 纬度
   * @param {number}  longitude       : 经度
   */
  setLocation: function (latitude, longitude) {
    exec(null, null, 'TalkingDataSDK', 'setLocation', [latitude, longitude]);
  },

  /**
   * 开始跟踪某一页面，并自动结束上一页面的跟踪
   * @param {string}  pageName        : 页面名称
   */
  onPage: function (pageName) {
    exec(null, null, 'TalkingDataSDK', 'onPage', [pageName]);
  },

  /**
   * 开始跟踪某一页面，记录页面打开时间
   * @param {string}  pageName        : 页面名称
   */
  onPageBegin: function (pageName) {
    exec(null, null, 'TalkingDataSDK', 'onPageBegin', [pageName]);
  },

  /**
   * 结束某一页面的跟踪，记录页面的关闭时间
   * 此方法与onPageBegin方法结对使用
   * @param {string}  pageName        : 页面名称，请跟onPageBegin方法的页面名称保持一致
   */
  onPageEnd: function (pageName) {
    exec(null, null, 'TalkingDataSDK', 'onPageEnd', [pageName]);
  },

  /**
   * 唤醒
   * @param {string}  link            : 唤醒应用的链接
   */
  onReceiveDeepLink: function (link) {
    exec(null, null, 'TalkingDataSDK', 'onReceiveDeepLink', [link]);
  },

  /**
   * 注册
   * @param {string}  profileId       : 用户账号
   * @param {object}  profile         : 账户属性
   * @param {string}  invitationCode  : 邀请码
   */
  onRegister: function (profileId, profile, invitationCode) {
    var profileJson = JSON.stringify(profile);
    exec(null, null, 'TalkingDataSDK', 'onRegister', [profileId, profileJson, invitationCode]);
  },

  /**
   * 登录
   * @param {string}  profileId       : 用户账号
   * @param {object}  profile         : 账户属性
   */
  onLogin: function (profileId, profile) {
    var profileJson = JSON.stringify(profile);
    exec(null, null, 'TalkingDataSDK', 'onLogin', [profileId, profileJson]);
  },

  /**
   * 收藏
   * @param {string}  category        : 收藏类别
   * @param {string}  content         : 收藏内容
   */
  onFavorite: function (category, content) {
    exec(null, null, 'TalkingDataSDK', 'onFavorite', [category, content]);
  },

  /**
   * 分享
   * @param {string}  profileId       : 用户账号
   * @param {string}  content         : 分享内容
   */
  onShare: function (profileId, content) {
    exec(null, null, 'TalkingDataSDK', 'onShare', [profileId, content]);
  },

  /**
   * 触发自定义事件
   * @param {string}  eventId         : 自定义事件的ID
   * @param {number}  eventValue      : 自定义事件的数值
   * @param {object}  eventData       : 自定义事件的数据，Json格式
   */
  onEvent: function (eventId, eventValue, eventData) {
    if (!eventData) {
      eventData = null;
    }
    exec(null, null, 'TalkingDataSDK', 'onEvent', [eventId, eventValue, eventData]);
  },

  /**
   * 添加自定义事件全局参数
   * @param {string}  key             : 参数的key
   * @param {string}  value           : 参数的value，string或number类型
   */
  setGlobalKV: function (key, value) {
    exec(null, null, 'TalkingDataSDK', 'setGlobalKV', [key, value]);
  },

  /**
   * 删除自定义事件全局参数
   * @param {string}  key             : 参数的key
   */
  removeGlobalKV: function (key) {
    exec(null, null, 'TalkingDataSDK', 'removeGlobalKV', [key]);
  },
};

module.exports = TalkingDataSDK;

});
